package static

import (
	"flag"
	"time"

	"github.com/open-io/oio-exporter/common"
	"github.com/open-io/oio-exporter/daemon"
)

var confInterval = time.Duration(0)

func InitFlags(fs *flag.FlagSet) {
	fs.DurationVar(&confInterval, "static.interval", confInterval, "[static] interval between polls")
}

type staticDaemon struct {
	daemon.Daemon

	namespace string
	localname string
	rack      string
}

func MakeDaemon(namespace, localname, rack string) *staticDaemon {
	return &staticDaemon{
		namespace: namespace,
		localname: localname,
		rack:      rack,
	}
}

func (d *staticDaemon) ID() string {
	return "Static"
}

func (d *staticDaemon) Interval() time.Duration {
	return confInterval
}

func (d *staticDaemon) Collect(m *common.MetricData) error {
	m.Set(&common.Metric{
		Name: "static_host",
		Labels: [][]string{
			[]string{"namespace", d.namespace},
			[]string{"localname", d.localname},
			[]string{"rack", d.rack},
		},
		Value: float64(time.Now().Unix()),
	})

	return nil
}
